pub struct InputInitCall<'scope> { /* private fields */ }Expand description
Initialization-only input capability which can register devices.
Implementations
Sourceimpl InputInitCall<'_>
impl InputInitCall<'_>
pub const fn input_api_version(&self) -> InputApiVersion
pub const fn logger(&self) -> ScopedLogger<'_>
Sourcepub fn register_device(&self, device: &InputDeviceRegistration<'_>) -> SdkResult
pub fn register_device(&self, device: &InputDeviceRegistration<'_>) -> SdkResult
Registers one input device during scs_input_init.
Errors
Returns the SDK error reported by SCS when the device name, input list, callbacks, or current lifecycle state are rejected by the game.