ChannelValue

Trait ChannelValue 

pub trait ChannelValue: SdkValue { }
Value types which can be requested from an SCS telemetry channel.

The game validates whether a particular channel supports the requested representation. For example, placement channels commonly accept placement, vector, or Euler representations, while u32 channels commonly accept u64. Unsupported requests return SdkError::UnsupportedType.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors